variable "proxmox_apiuser" {
  type    = string
  default = "packer"
}

variable "proxmox_apitoken" {
  type    = string
  default = "changeme"
}

source "proxmox-iso" "debian-12" {
  template_name            = "debian-12"
  template_description     = "Debian 12.5, generated on ${timestamp()}"
  boot_wait                = "10s"
  boot_key_interval        = "200ms"
  boot_command             = ["<esc><wait1s>", "auto url=http://ks.int.metaunix.net/preseeds/debian-bookworm.cfg", "<enter><wait6m>"]

  os                       = "l26"
  cores                    = "2"
  sockets                  = "1"
  memory                   = "2048"
  disks {
    disk_size              = "10G"
    storage_pool           = "templates"
    type                   = "scsi"
  }
  network_adapters {
    bridge                 = "vmbr0"
    model                  = "virtio"
  }

  proxmox_url              = "https://kamino.int.metaunix.net:8006/api2/json/"
  insecure_skip_tls_verify = true
  username                 = "${var.proxmox_apiuser}"
  password                 = "${var.proxmox_apitoken}"
  node                     = "geonosis"

  iso_url                  = "https://cdimage.debian.org/debian-cd/current/amd64/iso-cd/debian-12.5.0-amd64-netinst.iso"
  iso_checksum             = "sha256:013f5b44670d81280b5b1bc02455842b250df2f0c6763398feb69af1a805a14f"
  iso_storage_pool         = "iso"
  unmount_iso              = true
  iso_download_pve         = true

  ssh_username             = "xadmin"
  ssh_password             = "packer"
  ssh_timeout              = "20m"
}

build {
  sources = ["source.proxmox-iso.debian-12"]
}
